# Trade of Times

**WARNING: Currently in test stage! EXPECT errors.**

Trade of Times is an experimental, demonstrative RPG game,
which supports both singleplayer and multiplayer modes. Its
multiplayer (primary focus and demonstration) is peer-to-peer,
and based on Peertable; while its GUI is based on wxPython.